# Specification

## Overview

A button is a call to action that allows people to make a selection, navigate, send data, or take other types of actions.

This specification is an extension of [SDS Button Specification &rarr;](https://github.com/salesforce-ux/salesforce-design-system/blob/main/packages/sds-components/src/button/button.spec.md)

### Anatomy and Appearance

#### DOM Structure

[SDS Button - DOM Structure &rarr;](https://github.com/salesforce-ux/salesforce-design-system/blob/main/packages/sds-components/src/button/button.spec.md#dom-structure)

## API

### Properties & Attributes

[SDS Button - Properties & Attributes &rarr;](https://github.com/salesforce-ux/salesforce-design-system/blob/main/packages/sds-components/src/button/button.spec.md#properties--attributes)

Below are the list of attributes for `slds-button` in addition to existing ones for`sds-button`.

| Attribute | Type   | Values                                                                  | Default Value | Description                       |
| --------- | ------ | ----------------------------------------------------------------------- | ------------- | --------------------------------- |
| `stretch` | `bool` | `true/false`                                                            | `false`       | Toggle stretch styling of button  |
| `variant` | `enum` | `base/neutral/brand/brand-outline/destructive/destructive-text/success/inverse` | `neutral`        | Determines the type of the button |

#### Styling Hooks

#### Default

| Property Name                                       | CSS Property       | Fallback Value    | Description                                                    |
| --------------------------------------------------- | ------------------ | ----------------- | -------------------------------------------------------------- |
| `--slds-c-button-icon-color-foreground`             | `color`            | `currentcolor`    | Default icon color for buttons                                 |
| `--slds-c-button-neutral-spacing-inline`            | `padding-inline`   | `1rem`            | Default inline padding for buttons                             |
| `--slds-c-button-neutral-spacing-block`             | `padding-block`    | `0`               | Default vertical padding spacing for buttons                   |
| `--slds-c-button-neutral-font-lineheight`           | `line-height`      | `1.875rem`        | Default line-height for buttons                                |
| `--slds-c-button-neutral-radius-border`             | `border-radius`    | `0.25rem`         | Default border-radius for buttons                              |
| `--slds-c-button-neutral-color-background`          | `background-color` | `#fff`            | Default background color for neutral buttons                   |
| `--slds-c-button-neutral-color-background-hover`    | `background-color` | `#f3f3f3`         | Default background color for neutral buttons on hover          |
| `--slds-c-button-neutral-color-background-active`   | `background-color` | `#e5e5e5`         | Default background color for neutral buttons on active         |
| `--slds-c-button-neutral-color-background-focus`    | `background-color` | `#f3f3f3`         | Default background color for neutral buttons on focus          |
| `--slds-c-button-neutral-color-background-disabled` | `background-color` | `#fff`            | Default background color for neutral buttons when disabled     |
| `--slds-c-button-neutral-color-border`              | `border-color`     | `#c9c9cb`         | Default border color for neutral buttons                       |
| `--slds-c-button-neutral-color-border-hover`        | `border-color`     | `#c9c9cb`         | Default border color for neutral buttons on hover              |
| `--slds-c-button-neutral-color-border-active`       | `border-color`     | `#0176d3`         | Default border color for neutral buttons on active             |
| `--slds-c-button-neutral-color-border-disabled`     | `border-color`     | `#c9c9c9`         | Default border color for neutral buttons when disabled         |
| `--slds-c-button-neutral-text-color`                | `color`            | `#0b5cab`         | Default text color for neutral buttons                         |
| `--slds-c-button-neutral-text-color-hover`          | `color`            | `#014486`         | Default text color for neutral buttons on hover                |
| `--slds-c-button-neutral-text-color-active`         | `color`            | `#014486`         | Default text color for neutral buttons on active               |
| `--slds-c-button-neutral-text-color-focus`          | `color`            | `#014486`         | Default text color for neutral buttons on focus                |
| `--slds-c-button-neutral-text-color-disabled`       | `color`            | `#c9c9c9`         | Default text color for neutral buttons when disabled           |
| `--slds-c-button-neutral-shadow`                    | `box shadow color` | `none`            | Default box shadow color for neutral buttons (Must be defined) |
| `--slds-c-button-neutral-shadow-focus`              | `box shadow color` | `#0176d3 0 0 3px` | Default box shadow color for neutral buttons when focused      |

#### Brand

| Property Name                                       | CSS Property       | Fallback Value    | Description                                                    |
| --------------------------------------------------- | ------------------ | ----------------- | -------------------------------------------------------------- |
| `--slds-c-button-brand-color-background`            | `background-color` | `#0176d3`         | Default background color for brand buttons                     |
| `--slds-c-button-brand-color-background-hover`      | `background-color` | `#014486`         | Default background color for brand buttons on hover            |
| `--slds-c-button-brand-color-background-focus`      | `background-color` | `#014486`         | Default background color for brand buttons on focus            |
| `--slds-c-button-brand-color-background-active`     | `background-color` | `032d60`          | Default background color for brand buttons on active           |
| `--slds-c-button-brand-color-border`                | `border-color`     | `#0176d3`         | Default border color for brand buttons                         |
| `--slds-c-button-brand-color-border-hover`          | `border-color`     | `#014486`         | Default border color for brand buttons on hover                |
| `--slds-c-button-brand-color-border-focus`          | `border-color`     | `#014486`         | Default border color for brand buttons on focus                |
| `--slds-c-button-brand-color-border-active`         | `border-color`     | `#032d60`         | Default border color for brand buttons on active               |
| `--slds-c-button-brand-text-color`                  | `color`            | `#fff`            | Default text color for brand buttons                           |
| `--slds-c-button-brand-text-color-hover`            | `color`            | `#fff`            | Default text color for brand buttons on hover                  |
| `--slds-c-button-brand-text-color-focus`            | `color`            | `#fff`            | Default text color for brand buttons on focus                  |
| `--slds-c-button-brand-text-color-active`           | `color`            | `#fff`            | Default text color for brand buttons on active                 |

## Accessibility

[SDS Button - Accessibility &rarr;](https://github.com/salesforce-ux/salesforce-design-system/blob/main/packages/sds-components/src/button/button.spec.md#accessibility)

## Internationalization

[SDS Button - Internationalization &rarr;](https://github.com/salesforce-ux/salesforce-design-system/blob/main/packages/sds-components/src/button/button.spec.md#internationalization)

## Test Plan

[SDS Button - Test Plan &rarr;](https://github.com/salesforce-ux/salesforce-design-system/blob/main/packages/sds-components/src/button/button.spec.md#test-plan)
